==> hibernate-search-engine-6.1.0.Beta1.jar: META-INF/versions/9/module-info.java <==
/* synthetic */ module org.hibernate.search.engine {
    requires org.hibernate.search.util.common;
    requires org.jboss.logging;

    exports org.hibernate.search.engine;
    exports org.hibernate.search.engine.backend;
    exports org.hibernate.search.engine.backend.analysis;
    exports org.hibernate.search.engine.backend.common;
    exports org.hibernate.search.engine.backend.common.spi;
    exports org.hibernate.search.engine.backend.document;
    exports org.hibernate.search.engine.backend.document.model.dsl;
    exports org.hibernate.search.engine.backend.document.model.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.backend.document.model.dsl.spi;
    exports org.hibernate.search.engine.backend.document.model.spi;
    exports org.hibernate.search.engine.backend.document.spi;
    exports org.hibernate.search.engine.backend.index;
    exports org.hibernate.search.engine.backend.index.spi;
    exports org.hibernate.search.engine.backend.mapping.spi;
    exports org.hibernate.search.engine.backend.metamodel;
    exports org.hibernate.search.engine.backend.orchestration.spi;
    exports org.hibernate.search.engine.backend.schema.management.spi;
    exports org.hibernate.search.engine.backend.scope;
    exports org.hibernate.search.engine.backend.scope.spi;
    exports org.hibernate.search.engine.backend.session.spi;
    exports org.hibernate.search.engine.backend.spi;
    exports org.hibernate.search.engine.backend.types;
    exports org.hibernate.search.engine.backend.types.converter;
    exports org.hibernate.search.engine.backend.types.converter.runtime;
    exports org.hibernate.search.engine.backend.types.converter.runtime.spi;
    exports org.hibernate.search.engine.backend.types.converter.spi;
    exports org.hibernate.search.engine.backend.types.dsl;
    exports org.hibernate.search.engine.backend.types.spi;
    exports org.hibernate.search.engine.backend.work.execution;
    exports org.hibernate.search.engine.backend.work.execution.spi;
    exports org.hibernate.search.engine.cfg;
    exports org.hibernate.search.engine.cfg.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.cfg.spi;
    exports org.hibernate.search.engine.common.dsl.spi;
    exports org.hibernate.search.engine.common.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.common.resources.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.common.spi;
    exports org.hibernate.search.engine.common.timing;
    exports org.hibernate.search.engine.common.timing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.common.timing.spi;
    exports org.hibernate.search.engine.environment.bean;
    exports org.hibernate.search.engine.environment.bean.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.environment.bean.spi;
    exports org.hibernate.search.engine.environment.classpath.spi;
    exports org.hibernate.search.engine.environment.thread.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.environment.thread.spi;
    exports org.hibernate.search.engine.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.logging.impl to org.jboss.logging;
    exports org.hibernate.search.engine.logging.spi;
    exports org.hibernate.search.engine.mapper.mapping.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.mapper.mapping.building.spi;
    exports org.hibernate.search.engine.mapper.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.mapper.mapping.spi;
    exports org.hibernate.search.engine.mapper.model.spi;
    exports org.hibernate.search.engine.mapper.scope.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.mapper.scope.spi;
    exports org.hibernate.search.engine.reporting;
    exports org.hibernate.search.engine.reporting.impl to org.jboss.logging;
    exports org.hibernate.search.engine.reporting.spi;
    exports org.hibernate.search.engine.search.aggregation;
    exports org.hibernate.search.engine.search.aggregation.dsl;
    exports org.hibernate.search.engine.search.aggregation.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.aggregation.dsl.spi;
    exports org.hibernate.search.engine.search.aggregation.spi;
    exports org.hibernate.search.engine.search.common;
    exports org.hibernate.search.engine.search.common.spi;
    exports org.hibernate.search.engine.search.loading.spi;
    exports org.hibernate.search.engine.search.predicate;
    exports org.hibernate.search.engine.search.predicate.dsl;
    exports org.hibernate.search.engine.search.predicate.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.predicate.dsl.spi;
    exports org.hibernate.search.engine.search.predicate.factories;
    exports org.hibernate.search.engine.search.predicate.spi;
    exports org.hibernate.search.engine.search.projection;
    exports org.hibernate.search.engine.search.projection.dsl;
    exports org.hibernate.search.engine.search.projection.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.projection.dsl.spi;
    exports org.hibernate.search.engine.search.projection.spi;
    exports org.hibernate.search.engine.search.query;
    exports org.hibernate.search.engine.search.query.dsl;
    exports org.hibernate.search.engine.search.query.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.query.dsl.spi;
    exports org.hibernate.search.engine.search.query.spi;
    exports org.hibernate.search.engine.search.sort;
    exports org.hibernate.search.engine.search.sort.dsl;
    exports org.hibernate.search.engine.search.sort.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.sort.dsl.spi;
    exports org.hibernate.search.engine.search.sort.spi;
    exports org.hibernate.search.engine.search.timeout.spi;
    exports org.hibernate.search.engine.spatial;
    exports org.hibernate.search.engine.tenancy.spi;

    provides BeanConfigurer with EngineBeanConfigurer;

}

==> hibernate-search-engine-6.2.0.Beta1.jar: META-INF/versions/9/module-info.java <==
/* synthetic */ module org.hibernate.search.engine {
    /* transitive */ requires org.hibernate.search.util.common;
    requires org.jboss.logging;

    exports org.hibernate.search.engine;
    exports org.hibernate.search.engine.backend;
    exports org.hibernate.search.engine.backend.analysis;
    exports org.hibernate.search.engine.backend.common;
    exports org.hibernate.search.engine.backend.common.spi;
    exports org.hibernate.search.engine.backend.document;
    exports org.hibernate.search.engine.backend.document.model.dsl;
    exports org.hibernate.search.engine.backend.document.model.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.backend.document.model.dsl.spi;
    exports org.hibernate.search.engine.backend.document.model.spi;
    exports org.hibernate.search.engine.backend.document.spi;
    exports org.hibernate.search.engine.backend.index;
    exports org.hibernate.search.engine.backend.index.spi;
    exports org.hibernate.search.engine.backend.mapping.spi;
    exports org.hibernate.search.engine.backend.metamodel;
    exports org.hibernate.search.engine.backend.orchestration.spi;
    exports org.hibernate.search.engine.backend.reporting.spi;
    exports org.hibernate.search.engine.backend.schema.management.spi;
    exports org.hibernate.search.engine.backend.scope;
    exports org.hibernate.search.engine.backend.scope.spi;
    exports org.hibernate.search.engine.backend.session.spi;
    exports org.hibernate.search.engine.backend.spi;
    exports org.hibernate.search.engine.backend.types;
    exports org.hibernate.search.engine.backend.types.converter;
    exports org.hibernate.search.engine.backend.types.converter.runtime;
    exports org.hibernate.search.engine.backend.types.converter.runtime.spi;
    exports org.hibernate.search.engine.backend.types.converter.spi;
    exports org.hibernate.search.engine.backend.types.dsl;
    exports org.hibernate.search.engine.backend.types.spi;
    exports org.hibernate.search.engine.backend.work.execution;
    exports org.hibernate.search.engine.backend.work.execution.spi;
    exports org.hibernate.search.engine.cfg;
    exports org.hibernate.search.engine.cfg.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.cfg.spi;
    exports org.hibernate.search.engine.common;
    exports org.hibernate.search.engine.common.dsl.spi;
    exports org.hibernate.search.engine.common.execution.spi;
    exports org.hibernate.search.engine.common.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.common.resources.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.common.resources.spi;
    exports org.hibernate.search.engine.common.schema.management;
    exports org.hibernate.search.engine.common.spi;
    exports org.hibernate.search.engine.common.timing;
    exports org.hibernate.search.engine.common.timing.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.common.timing.spi;
    exports org.hibernate.search.engine.environment.bean;
    exports org.hibernate.search.engine.environment.bean.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.environment.bean.spi;
    exports org.hibernate.search.engine.environment.classpath.spi;
    exports org.hibernate.search.engine.environment.thread.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.environment.thread.spi;
    exports org.hibernate.search.engine.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.logging.impl to org.jboss.logging, org.hibernate.search.engine;
    exports org.hibernate.search.engine.logging.spi;
    exports org.hibernate.search.engine.mapper.mapping.building.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.mapper.mapping.building.spi;
    exports org.hibernate.search.engine.mapper.mapping.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.mapper.mapping.spi;
    exports org.hibernate.search.engine.mapper.model.spi;
    exports org.hibernate.search.engine.mapper.scope.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.mapper.scope.spi;
    exports org.hibernate.search.engine.reporting;
    exports org.hibernate.search.engine.reporting.impl to org.jboss.logging, org.hibernate.search.engine;
    exports org.hibernate.search.engine.reporting.spi;
    exports org.hibernate.search.engine.search.aggregation;
    exports org.hibernate.search.engine.search.aggregation.dsl;
    exports org.hibernate.search.engine.search.aggregation.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.aggregation.dsl.spi;
    exports org.hibernate.search.engine.search.aggregation.spi;
    exports org.hibernate.search.engine.search.common;
    exports org.hibernate.search.engine.search.common.spi;
    exports org.hibernate.search.engine.search.highlighter;
    exports org.hibernate.search.engine.search.highlighter.dsl;
    exports org.hibernate.search.engine.search.highlighter.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.highlighter.dsl.spi;
    exports org.hibernate.search.engine.search.highlighter.spi;
    exports org.hibernate.search.engine.search.loading.spi;
    exports org.hibernate.search.engine.search.predicate;
    exports org.hibernate.search.engine.search.predicate.definition;
    exports org.hibernate.search.engine.search.predicate.dsl;
    exports org.hibernate.search.engine.search.predicate.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.predicate.dsl.spi;
    exports org.hibernate.search.engine.search.predicate.spi;
    exports org.hibernate.search.engine.search.projection;
    exports org.hibernate.search.engine.search.projection.definition;
    exports org.hibernate.search.engine.search.projection.definition.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.projection.definition.spi;
    exports org.hibernate.search.engine.search.projection.dsl;
    exports org.hibernate.search.engine.search.projection.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.projection.dsl.spi;
    exports org.hibernate.search.engine.search.projection.spi;
    exports org.hibernate.search.engine.search.query;
    exports org.hibernate.search.engine.search.query.dsl;
    exports org.hibernate.search.engine.search.query.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.query.dsl.spi;
    exports org.hibernate.search.engine.search.query.spi;
    exports org.hibernate.search.engine.search.sort;
    exports org.hibernate.search.engine.search.sort.dsl;
    exports org.hibernate.search.engine.search.sort.dsl.impl to org.hibernate.search.engine;
    exports org.hibernate.search.engine.search.sort.dsl.spi;
    exports org.hibernate.search.engine.search.sort.spi;
    exports org.hibernate.search.engine.search.timeout.spi;
    exports org.hibernate.search.engine.spatial;
    exports org.hibernate.search.engine.tenancy.spi;

    provides BeanConfigurer with EngineBeanConfigurer;

}
